@@ -11,5 +11,9 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from deluca.agents._bang_bang import BangBang
+from deluca.agents._pid import PID
+from deluca.agents._random import Random
+from deluca.agents._zero import Zero
 
-__all__ = ["BangBang, PID, Zero"]
+__all__ = ["BangBang", "PID", "Random", "Zero"]
